@@ -39,7 +39,7 @@ class Dataset(Entity):
 
     def _create_mpc(
         self,
-        name: str,
+        name: str = None,
         platform: str = "bigquery",
         env: str = None,
         description: str = None,
